function [names,p0,p1] = findname(s1,s2)
% FINDNAME Finding name (word) within a string.
%	[NAME,P] = FINDNAME(S1,S2) returns the string
%	matrix of full names matching the shorter
%	string and starting indices P of occurrences
%	of a shorter string in a longer one.
%	  Shorter string can have "wildcard" options:
%	'?' can stand for any non-blank character
%	while  '*' at the beginning or at the end
%	can stand for any number of pre- or appended
%	non-blank characters respectively.
%	[NAMES,P0,P1] = FINDNAME(S1,S2) returns
%	a string matrix of all names matching
%	a shorter string with wildcard options,
%	vectors P0 and P1 of starting and ending
%	indices of all matching occurences.

%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  02/05/95

 % Handle input .............................
if nargin < 2
  error(' Not enough input arguments')
end

 % Initialize output
p0 = []; p1 = []; names = [];

sz1 = size(s1);
ls2 = length(s2);
if sz1(2)<ls2 & sz1(1)==1
  ss = s1; s1 = s2; s2 = ss;
end
if ls2==0, return, end

 % Check the shorter string for wildcards ...
nn = find(s2=='?');
lq = length(nn);
s2(nn) = 32.01*ones(size(nn));
is_wc = s2([1 ls2])=='*';
s2 = s2(s2~='*');
ls2 = length(s2);

 % Extract all possible names ...............
if sz1(1)==1
  [names,p0,p1] = getnames(s1);
else
  names = s1; p0 = 1:sz1(1);
end
if ls2 == 0, return, end
szn = size(names);

 % If s2 is longer than any name, return empty
if ls2>szn(2), names=[]; p0=[]; p1=[]; return, end

lm = (szn(2)-ls2)*is_wc(1);
A = s2(ones(szn(1),1),:)';
ll = ls2-lq;
v_cnc = zeros(1,szn(1));
vl = max(.5,sum(names'~=' ')-ls2+1);
for jj=0:lm
  Ad = A-names(:,jj+(1:ls2))';
  if ls2>1
    vv = sum(~Ad)==ll;
    vv = vv & sum(abs(Ad)<.1)==ll;
  else
    vv = (~Ad) | (~ll)*(abs(Ad)>.1);
  end
  nn = find(vv);
  v_cnc(nn) = (jj+1)*ones(size(nn));
end
v_cnc = is_wc(2)*v_cnc+(~is_wc(2))*(v_cnc==vl);
nn = find(v_cnc);

 % Extract matching names ........
p0 = p0(nn);
p1 = p1(nn);
names = names(nn,:);
if p0==[], return, end

 % Remove blank padding ..........
szn = size(names);
lm = max(find(any(names([1 1:szn(1)],:)~=' ')));
names = names(:,1:lm);

