function  [names,no,nc] = getnames(string)

% GETNAMES  Finds all possible legal names in a string.
%	NAMES = GETNAMES(STRING)  extracts all consecutive
%	combinatons of characters which can be legal names for
%	MATLAB variables or functions.
%	[NAMES,NO,NC] = GETNAMES(STRING) also returns indices
%	NO and NC of beginnings and ends of these names.
%
%	Example:
%	>>names = extvar('yy = foo(x1.^2,a_1*c,flag)')
%
%	  names =
%
%	  yy
%	  foo
%	  x1
%	  a_1
%	  c
%	  flag

%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  5/15/94, 12/15/94


 % Handle input ...............................................
if nargin == 0
  help getnames
  return
end

 % Make string a single line ..........
string = string';
string = [' ' string(:)' ' '];

mask = 9*(string>='0'&string<='9');       % 9 is for numbers
mask = mask+9*(string=='_');              % 9 is for '_'
mask = mask+10*(string>='A'&string<='Z'); % 10 is for letters
mask = mask+10*(string>='a'&string<='z');

no = find(diff(mask)>9)+1;     % Beginnings
nc = find(diff(mask)<=-9)+1;   % Ends

nn = sort([no nc+.5]);
a = abs(diff([.5 nn]));
nn = nn(a-floor(a)>=.1);
no = nn(floor(nn)==nn);
nc = floor(nn(floor(nn)~=nn));

names = extract(string,no,nc); % Extraction
no = no-1;
nc = nc-2;

