function  vout = insert(vin,list,no,nc,nfill)

% INSERT  Inserting entries from matrix LIST into vector VIN
%	VOUT = INSERT(VIN,LIST,NO,NC,NFILL)
%	Inserts entries - rows of matrix LIST into
%	vector VIN.
%	Beginning of insertions are specified by vector NO
%	ends - by vector NC.
%	NFILL specifies the "filling" number in matrix LIST,
%	such as blanks for string matrix:
%	for each row of LIST only part up to the last number
%	different from NFILL is inserted into VIN.
%	Default values are blanks (#32) if LIST is string matrix
%	or zeros if LIST is numbers.


%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  8/22/94

nfilldflt = [0 32]; % Defaults for filling (0 for numbers
                    % or blank for strings)

 % Handle input .......................................
if nargin<5, nfill = nfilldflt(1+isstr(list)); end
if nargin<3
  error(' Not enough input arguments')
end
 % If inserts ends are not specified, make them equal
 % inserts beginnings
if nargin==3, nc = no; end

vin = vin(:)';
no = no(:)'; nc = nc(:)';
lmin = min(length(no),length(nc));
if size(list,1)==1
  list = list(ones(lmin,1),:);
end
lmin = min(lmin,size(list,1));
list = list(1:lmin,:);
no = no(1:lmin);
nc = nc(1:lmin);

l = length(vin);
szl = size(list);
a = ones(1,l);
a(no) = a(no)+l;
a(nc) = a(nc)-l;
a = cumsum(a);

aa = flipud(cumprod(rot90(list==nfill)))*l;
aa = aa+no(ones(szl(2),1),:);
[vout,a] = sort([a aa(:)']);
l = max(find(vout<=l));
list = list';
vout = [vin list(:)'];
vout = vout(a(1:l));

