function s = strrepl(s1,s2,s3,flag)
%STRREP String search and replace utility.
%	S = STRREP(S1,S2,S3,'all') replaces all occurrences of S2 in
%	S1 with S3 (equivalent to STRREP).
%	S = STRREP(S1,S2,S3)  Replaces only occurences which are
%	words themselves and not parts of bigger words.
%
%	Example:
% 	s1 = 'How much wood would a woodchuck chuck?';
%	strrepl(s1,'chuck','pack')        returns
%	  'How much wood would a woodchuck pack?',   while
%	strrepl(s1,'chuck','pack','all')  returns
%	  'How much wood would a woodpack pack?'
%
%	See also STRREP, FINDSTR, FINDNAME

%  Based on the STRREP.M program in MATLAB

%  Kirill K. Pankratov,  kirill@plume.mit.edu
%  02/05/95

is_name = 1;  % Default for "names" vs. any string

 % Handle input ...............................
if nargin < 3
  error(' Not enough input arguments')
end
if nargin==4
  is_name = ~strcmp(flag,'all');
end

% Take care of trivial cases:
%   s2 > s1,  s1 is empty  or  s2 is empty
if (length(s2)>length(s1)) | isempty(s2) | isempty(s1),
  s = s1;  return;
end

s1 = [s1(:)' ' '];

if is_name   % If only legal names (words) are to be replaced
  [names,p0,p1] = findname(s1,s2);

else         % If all coincidences are to be replaced
  ls2 = length(s2);
  p0 = findstr(s1,s2);
  p1 = p0+length(s2)-1;

end

list = s3(ones(size(p1)),:);
  % Insert new string
s = insert(s1,list,p0,p1+1);
s = s(1:length(s)-1);

